@@ -336,10 +336,7 @@ int Kwave::RecordALSA::initialize()
     unsigned buffer_time = 0; // ring buffer length in us
     snd_pcm_uframes_t period_frames = 0;
     snd_pcm_uframes_t buffer_frames = 0;
-    size_t n;
     snd_pcm_uframes_t start_threshold, stop_threshold;
-    const int start_delay = 0;
-    const int stop_delay = 0;
 
 //     qDebug("RecordALSA::initialize");
     Q_ASSERT(!m_initialized);
@@ -430,17 +427,14 @@ int Kwave::RecordALSA::initialize()
     }
     m_rate = rrate;
 
-    if ((buffer_time) == 0 && (buffer_frames) == 0) {
-	err = snd_pcm_hw_params_get_buffer_time_max(m_hw_params, &buffer_time, 0);
-	if (buffer_time > 500000) buffer_time = 500000;
-    }
+    err = snd_pcm_hw_params_get_buffer_time_max(m_hw_params, &buffer_time, 0);
+    Q_ASSERT(err >= 0);
+    if (buffer_time > 500000) buffer_time = 500000;
 
-    if ((period_time == 0) && (period_frames == 0)) {
-	if (buffer_time > 0)
-	    period_time = buffer_time / 4;
-	else
-	    period_frames = buffer_frames / 4;
-    }
+    if (buffer_time > 0)
+	period_time = buffer_time / 4;
+    else
+	period_frames = buffer_frames / 4;
 
     if (period_time > 0) {
 	err = snd_pcm_hw_params_set_period_time_near(m_handle, m_hw_params,
@@ -489,19 +483,11 @@ int Kwave::RecordALSA::initialize()
     err = snd_pcm_sw_params_set_avail_min(m_handle, m_sw_params, m_chunk_size);
 
     /* round up to closest transfer boundary */
-    n = buffer_size;
-    start_threshold = static_cast<snd_pcm_uframes_t>
-                      (m_rate * start_delay / 1000000);
-    if (start_delay <= 0) start_threshold += n;
-
-    if (start_threshold < 1) start_threshold = 1;
-    if (start_threshold > n) start_threshold = n;
+    start_threshold = qMax<snd_pcm_uframes_t>(1, buffer_size);
     err = snd_pcm_sw_params_set_start_threshold(m_handle, m_sw_params,
                                                 start_threshold);
     Q_ASSERT(err >= 0);
-    stop_threshold = static_cast<snd_pcm_uframes_t>
-                     (m_rate * stop_delay / 1000000);
-    if (stop_delay <= 0) stop_threshold += buffer_size;
+    stop_threshold = buffer_size;
 
     err = snd_pcm_sw_params_set_stop_threshold(m_handle, m_sw_params,
                                                stop_threshold);
@@ -554,7 +540,7 @@ int Kwave::RecordALSA::read(QByteArray &buffer, unsigned int offset)
     Q_ASSERT(m_chunk_size);
     if (!m_chunk_size) return 0;
 
-    unsigned int chunk_bytes = m_chunk_size * m_bytes_per_sample;
+    unsigned int chunk_bytes = Kwave::toUint(m_chunk_size) * m_bytes_per_sample;
     Q_ASSERT(chunk_bytes);
     if (!chunk_bytes) return 0;
 
@@ -573,7 +559,8 @@ int Kwave::RecordALSA::read(QByteArray &buffer, unsigned int offset)
     unsigned int samples = (length - offset) / m_bytes_per_sample;
 
     // do not read more than one chunk at a time
-    if (samples > m_chunk_size) samples = m_chunk_size;
+    if (samples > m_chunk_size)
+	samples = Kwave::toUint(m_chunk_size);
 
 #ifdef DEBUG
     // just for debugging: detect state changes of the device
@@ -616,7 +603,9 @@ int Kwave::RecordALSA::read(QByteArray &buffer, unsigned int offset)
     // try to read as much as the device accepts
     Q_ASSERT(samples);
     Q_ASSERT(offset + samples <= Kwave::toUint(buffer.size()));
-    int r = snd_pcm_readi(m_handle, buffer.data() + offset, samples);
+    int r = Kwave::toInt(
+	snd_pcm_readi(m_handle, buffer.data() + offset, samples)
+    );
 
     // handle all negative result codes
     if (r == -EAGAIN) {
